<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class EvolucaoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager  $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getEvolutionTab(array $paramsQuery): array
    {
        try {

            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder
                ->select([
                    'MUNICIPIO.NMMUNICIPIO AS CIDADEINTERLOCUTOR',
                    'ESTADO.NMESTADO AS ESTADOINTERLOCUTOR',
                    'EVOL.CDFILIAL',
                    'EVOL.NRCONTATO',
                    'EVOL.DTHREVOLCONT',
                    'EVOL.CDTIPOCONT',
                    'EVOL.IDSENEVOCONT',
                    'EVOL.IDTPEVOLCONT',
                    'EVOL.CDOPEREVOL',
                    'EVOL.CDMOTIEVOCON',
                    'EVOL.NRORG',
                    'EVOL.DTINCLUSAO',
                    'EVOL.DTULTATU',
                    'EVOL.NRORGINCLUSAO',
                    'EVOL.CDOPERINCLUSAO',
                    'EVOL.NRORGULTATU',
                    'EVOL.CDOPERULTATU',
                    'EVOL.NRRELACIONAPARC',
                    'EVOL.IDANEXOEVOLCONT',
                    'EVOL.TXEVOLCONT',
                    'EVOL.IDATIVO',
                    'EVOL.NRSEQRESULEVOL',
                    'EVOL.NRSEQEVOLCONT',
                    'EVOL.NRSEQCONTATO',
                    'EVOL.IDGERAFATURA',
                    'EVOL.NRSEQFILACONTA',
                    'EVOL.NRSEQINTERLOCUTOR',
                    'EVOL.CRM_NRORGTRAB',
                    'CAND.NRCANDIDATO',
                    'CAND.NRPARCNEGOCIO',
                    'OPER.NMOPERADOR',
                    'MOT.NMMOTIEVOCON',
                    'TIPO.NMTIPOCONT',
                    'REST.DESCRESULEVOL',
                    'FILACONT.DSFILACONTATO',
                    'FILACONT.DTPLANFILACONTA',
                    'FILACONT.CDOPERREAL',
                    'OPERTAREFA.NMOPERADOR AS NMOPERADORREAL',
                    'REST.IDGERPROXATIV',
                    'INTER.NMINTERLOCUTOR',
                    'FILACONT.NRSEQCLASSIFICATAREFA',
                    'CLASSTAREFA.DSCLASSIFICATAREFA'
                ])
                ->from('EVOLCONT', 'EVOL')
                ->leftJoin('EVOL', 'CRM_CANDIDATO', 'CAND', 'EVOL.NRSEQCONTATO = CAND.NRSEQCONTATO AND CAND.NRORG = EVOL.NRORG')
                ->leftJoin('EVOL', 'OPERADOR', 'OPER', 'EVOL.CDOPEREVOL = OPER.CDOPERADOR AND EVOL.NRORG = OPER.NRORG')
                ->leftJoin('EVOL', 'MOTIEVOLCONT', 'MOT', 'EVOL.CDMOTIEVOCON = MOT.CDMOTIEVOCON AND EVOL.NRORG = MOT.NRORG')
                ->leftJoin('EVOL', 'CRM_RESULTEVOL', 'REST', 'EVOL.NRSEQRESULEVOL = REST.NRSEQRESULEVOL AND EVOL.NRORG = REST.NRORG')
                ->leftJoin('EVOL', 'TIPOCONT', 'TIPO', 'EVOL.CDTIPOCONT = TIPO.CDTIPOCONT AND EVOL.NRORG = TIPO.NRORG')
                ->leftJoin('EVOL', 'CRM_INTERLOCUTOR', 'INTER', 'INTER.NRSEQINTERLOCUTOR = EVOL.NRSEQINTERLOCUTOR AND INTER.NRORG = EVOL.NRORG')
                ->leftJoin('EVOL', 'ESTADO', 'ESTADO', 'ESTADO.NRORG = INTER.NRORG AND ESTADO.CDPAIS = INTER.CDPAIS AND ESTADO.SGESTADO = INTER.SGESTADO')
                ->leftJoin('EVOL', 'MUNICIPIO', 'MUNICIPIO', 'MUNICIPIO.NRORG = INTER.NRORG AND MUNICIPIO.CDPAIS = INTER.CDPAIS AND MUNICIPIO.SGESTADO = INTER.SGESTADO AND MUNICIPIO.CDMUNICIPIO = INTER.CDMUNICIPIO')
                ->leftJoin('EVOL', 'FILACONTATO', 'FILACONT', 'FILACONT.NRSEQFILACONTA = EVOL.NRSEQFILACONTA AND FILACONT.NRORG = EVOL.NRORG AND FILACONT.IDATIVO = :IDATIVO')
                ->leftJoin('EVOL', 'CRM_CLASSIFICATAREFA', 'CLASSTAREFA', 'FILACONT.NRSEQCLASSIFICATAREFA = CLASSTAREFA.NRSEQCLASSIFICATAREFA')
                ->leftJoin('EVOL', 'OPERADOR', 'OPERTAREFA', 'OPERTAREFA.CDOPERADOR = FILACONT.CDOPERREAL')
                ->where('EVOL.NRORG = :NRORG')
                ->andWhere('EVOL.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->andWhere('EVOL.NRCONTATO = :NRCONTATO')
                ->andWhere('EVOL.NRSEQCONTATO = :NRSEQCONTATO');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('IDATIVO', $paramsQuery['IDATIVO']);
            $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsQuery['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('NRCONTATO', $paramsQuery['NRCONTATO']);
            $queryBuilder->setParameter('NRSEQCONTATO', $paramsQuery['NRSEQCONTATO']);
            return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
