<?php

namespace CRM\Service;

use CRM\Util\Utilities;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use CRM\Factory\EvolucaoFactory;
use Teknisa\Libs\Util\Environment;

class EvolucaoService
{
    protected $newCode;
    protected $connection;
    protected $Environment;
    protected $EvolucaoFactory;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, EvolucaoFactory $EvolucaoFactory)
    {
        $this->EvolucaoFactory                    = $EvolucaoFactory;
        $this->Environment                        = $Environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    /**
     * Get evolution tab data based on provided parameters.
     *
     * @param array $params An array of parameters containing NRCONTATO and NRSEQCONTATO.
     * @return array The evolution tab data.
     * @throws \Exception If an error occurs while retrieving the data.
     */
    public function getEvolutionTab(array $params): array
    {
        try {
            // Get the organization number
            $nrorg = $this->Environment->getNrOrg();

            // Prepare the query parameters
            $paramsQuery = [
                'NRORG' => $nrorg,
                'IDATIVO' => 'S',
                'CRM_NRORGTRAB' => $nrorg,
                'NRCONTATO' => $params['NRCONTATO'], // Ensure that NRCONTATO is provided
                'NRSEQCONTATO' => $params['NRSEQCONTATO'], // Ensure that NRSEQCONTATO is provided
            ];

            // Retrieve evolution tab data using the factory
            return $this->EvolucaoFactory->getEvolutionTab($paramsQuery);
        } catch (\Exception $e) {
            // Handle the exception appropriately, such as logging or reporting the error
            throw $e; // Or do something more specific here, like throwing a custom exception
        }
    }
}
